# Latex Project and Bibliography Management Utilities

Paperman is a command line utility designed to accelerate your latex writing workflow by automating tasks as:
 * finding and copying frequently used images, bibtex entries and input tex-files from your other documents
 * identifying unused image files and bibtex entries in your latex project
 * maintaining consistent capitalization of, e.g., names in titles in bibtex entries
 * maintaining consistent usage of ISO4 abbreviated or full journal names
 * renaming and organizing downloaded bib and pdf files
